/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
var app = {
    // Application Constructor
    initialize: function() {
        this.bindEvents();
    },
    // Bind Event Listeners
    //
    // Bind any events that are required on startup. Common events are:
    // 'load', 'deviceready', 'offline', and 'online'.
    bindEvents: function() {
        document.addEventListener('deviceready', this.onDeviceReady, false);
        
    },
    // deviceready Event Handler
    //
    // The scope of 'this' is the event. In order to call the 'receivedEvent'
    // function, we must explicity call 'app.receivedEvent(...);'
    onDeviceReady: function() {
        app.receivedEvent('deviceready');
        
        ons.setDefaultDeviceBackButtonListener(function() {
            if (navigator.notification.confirm("Are you sure to close the app?", 
                function(index) {
                    if (index == 1) { // OK button
                        navigator.app.exitApp(); // Close the app
                    }
                }
            ));
        });

        // Open any external link with InAppBrowser Plugin
        $(document).on('click', 'a[href^=http], a[href^=https]', function(e){

            e.preventDefault();
            var $this = $(this); 
            var target = $this.data('inAppBrowser') || '_blank';

            window.open($this.attr('href'), target);

        });
        // Admob Plugin here
		 var admobid = {};
    if( /(android)/i.test(navigator.userAgent) ) { // for android
        admobid = {
            banner: 'ca-app-pub-1089631784540973/4504097441',
            interstitial: 'ca-app-pub-1089631784540973/4504097441'
        };
    } else if(/(ipod|iphone|ipad)/i.test(navigator.userAgent)) { // for ios
        admobid = {
            banner: 'ca-app-pub-xxx/zzz',
            interstitial: 'ca-app-pub-xxx/kkk'
        };
    } else { // for windows phone
        admobid = {
            banner: 'ca-app-pub-xxx/zzz',
            interstitial: 'ca-app-pub-xxx/kkk'
        };
    }


    // It will display smart banner at top center, using the default options
    if(AdMob) AdMob.createBanner( {
    adId: admobid.banner, 
    position: AdMob.AD_POSITION.BOTTOM_CENTER, 
    autoShow: true } );

    // Prepare and load ad resource in background, e.g. at begining of game level
    if(AdMob) AdMob.prepareInterstitial( {adId:admobid.interstitial, autoShow:false} );

    // Show the interstitial later, e.g. at end of game level
    if(AdMob) AdMob.showInterstitial();

		
		// Admob code here
		
        // Initialize Push Notifications
        // Uncomment the following initialization when you have made the appropriate configuration for iOS - http://goo.gl/YKQL8k and for Android - http://goo.gl/SPGWDJ
        //app.initPushwoosh();
        
    },
    // Update DOM on a Received Event
    receivedEvent: function(id) {
        //var parentElement = document.getElementById(id);
        //var listeningElement = parentElement.querySelector('.listening');
        //var receivedElement = parentElement.querySelector('.received');

        //listeningElement.setAttribute('style', 'display:none;');
        //receivedElement.setAttribute('style', 'display:block;');

        console.log('Received Event: ' + id);
    },
	
	
    // Register device for Push Notifications
    initPushwoosh: function() {
        var pushNotification = window.plugins.pushNotification;

		if(device.platform == "Android") {
			registerPushwooshAndroid();
		}
        if (device.platform == "iPhone" || device.platform == "iOS") {
            registerPushwooshIOS();
        }
    }
    
};

(function() {
    var app = angular.module('sensationApp', ['onsen.directives', 'ngTouch', 'ngSanitize', 'angular-carousel', 'google-maps'.ns(), 'appLocalStorage', 'LocalStorageModule', 'ui.map', 'ui.event', 'nvd3']);
    
    app.config(['$httpProvider', function($httpProvider) {

        $httpProvider.defaults.headers.common['Cache-Control'] = 'no-cache';
        $httpProvider.defaults.cache = false;

    }]);
    
    // Home Controller
    app.controller('HomeController', function($scope, Data) {
        
        $scope.items = Data.items;

        $scope.showDetail = function(index){
            var selectedItem = $scope.items[index];
            Data.selectedItem = selectedItem;
            $scope.appNavigator.pushPage(selectedItem.page, {title: selectedItem.title, animation: 'slide'});
        }
        
    });
	
	 // Menu Controller
    app.controller('MenuController', function($scope, MenuData) {
        
        $scope.items = MenuData.items;

        $scope.showDetail = function(index){
            var selectedItem = $scope.items[index];
            MenuData.selectedItem = selectedItem;
			
		$scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        },

            $scope.appNavigator.pushPage(selectedItem.page, {animation: 'none'});
            
        }
        
    });
	
	// Home Page Ad Management Controller
    app.controller('homeAdmgtsController', function($scope, $http, AddmgtData) {
        
        $('.loading').show();
        
        var getData = function ($done) {
        
            $http({method: 'GET', url: AddmgtData.url}).
            success(function(data, status, headers, config) {
                $scope.posts = data.posts;

                $('.loading').hide();
                if ($done) { $done(); }

                if ($scope.posts.length < 1)
                {
                    $scope.msg = "Nothing found.";
                }else{
                    $scope.msg = undefined;
                }

                var page = 1;
                // Define the number of the posts in the page
                var pageSize = 2;

                $scope.paginationLimit = function(data) {
                return pageSize * page;
                };

                $scope.hasMoreItems = function() {
                return page < ($scope.posts.length / pageSize);
                };

                $scope.showMoreItems = function() {
                page = page + 1;       
                }; 

            }).
            error(function(data, status, headers, config) {
            $('.loading').hide();
            $scope.msg = '' + status;
            if ($done) { $done(); }
            });
        
        }
            
        // Initial Data Loading
        getData();

        $scope.load = function($done) {
            getData($done);
        };
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.posts[index];
        AddmgtData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('hmadmgt.html', selectedItem);
        }
        
    });
    
    // Home Page Ad Management Controller
    app.controller('homeAdmgtController', function($scope, AddmgtData, $sce) {
        $scope.item = AddmgtData.selectedItem;

        $scope.content = $sce.trustAsHtml($scope.item.content);

        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_system');
        }

        $scope.sharePost = function () {

            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.url;

            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }

     });
	 
	 // End Page Ad Management
    
	    // RSS single Menu Controller
    app.controller('RsssingleController', function($scope, Menu3Data) {
        
        $scope.items = Menu3Data.items;

        $scope.showDetail = function(index){
            var selectedItem = $scope.items[index];
            Menu3Data.selectedItem = selectedItem;

            $scope.appNavigator.pushPage(selectedItem.page, {animation: 'none'});
            
        }
        
    });
    
	
	// jQuery Dialog: Dialog Controller
	app.controller('DialogController', function($scope) {

		var iframe = $('<iframe frameborder="0" marginwidth="0" marginheight="0" allowfullscreen></iframe>');

		var w = $(window).width();
		var h = $(window).height();

		var dialog = $('<div class="iframe-container"></div>').append(iframe).appendTo('body').dialog({
			autoOpen: false,
			modal: true,
			resizable: false,
			width: w,
			height: h
		});

		$scope.show = function () {
			var title = 'Colaba Times';
			iframe.attr({
				src: 'http://colabatimes.com/'
			});
			dialog.dialog('option', 'title', title).dialog('open');
		}


	 });


	 
		

	 
    // Plugins Controller
    app.controller('PluginsController', function($scope, PluginsData) {
        $scope.items = PluginsData.items;
            
        $scope.showDetail = function(index){
            var selectedItem = $scope.items[index];
            PluginsData.selectedItem = selectedItem;
            $scope.appNavigator.pushPage('plugins/' + selectedItem.page, {title: selectedItem.title, animation: 'slide'});

        }
        
    });
    
	 // News Controller
    app.controller('NewsController', function($scope, $http, NewsData) {
        
        $scope.news = [];
        
        $http({method: 'GET', url: NewsData.url}).
        success(function(data, status, headers, config) {
            $scope.news = data.result;
            $scope.letterLimit = NewsData.letterLimit;
        }).
        error(function(data, status, headers, config) {

        });
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.news[index];
        NewsData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('new.html', selectedItem);
        }
        
        // getNews() function()
        $scope.getNews = function() {
            // Filter News by $scope.search
            return $scope.news.filter(function(item) {
                
                // Filter News by Title
                var itemDoesMatch = !$scope.search ||
                item.title.toLowerCase().indexOf($scope.search.toLowerCase()) > -1;
                
                // Filter News by Title or Body
                //var itemDoesMatch = !$scope.search ||
                //item.title.toLowerCase().indexOf($scope.search.toLowerCase()) > -1 || 
                //item.body.toLowerCase().indexOf($scope.search.toLowerCase()) > -1;
                
                return itemDoesMatch;
            });
        };

        // Search Detail function()
        $scope.showSearchDetail = function(index) {
        var items = $scope.getNews();
        var selectedItem = items[index];
        NewsData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('new.html', selectedItem);
        }
        
    });
    
    // New Controller
    app.controller('NewController', function($scope, NewsData) {
        $scope.item = NewsData.selectedItem;
     });
    
// Letest News Controller
    app.controller('LatestNewsController', function($scope, $http, LatestnewsData) {
        
        $scope.news = [];
        
        $http({method: 'GET', url: LatestnewsData.url}).
        success(function(data, status, headers, config) {
            $scope.news = data.result;
            $scope.letterLimit = LatestnewsData.letterLimit;
        }).
        error(function(data, status, headers, config) {

        });
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.news[index];
        LatestnewsData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/latest-new.html', selectedItem);
        }
        
        // getNews() function()
        $scope.getNews = function() {
            // Filter News by $scope.search
            return $scope.news.filter(function(item) {
                
                // Filter Latest News by Title
                var itemDoesMatch = !$scope.search ||
                item.title.toLowerCase().indexOf($scope.search.toLowerCase()) > -1;
                
                // Filter News by Title or Body
                //var itemDoesMatch = !$scope.search ||
                //item.title.toLowerCase().indexOf($scope.search.toLowerCase()) > -1 || 
                //item.body.toLowerCase().indexOf($scope.search.toLowerCase()) > -1;
                
                return itemDoesMatch;
            });
        };

        // Search Detail function()
        $scope.showSearchDetail = function(index) {
        var items = $scope.getNews();
        var selectedItem = items[index];
        LatestnewsData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/latest-new.html', selectedItem);
        }
        
    });
    
    // Latest New Controller LatestNewController
    app.controller('LatestNewController', function($scope, LatestnewsData) {
        $scope.item = LatestnewsData.selectedItem;
     });
	
	
	 // Home Service menu Controller
    app.controller('HomesrvsController', function($scope, HomesrvcData) {
        $scope.items = HomesrvcData.items;
            
        $scope.showDetail = function(index){
            var selectedItem = $scope.items[index];
            HomesrvcData.selectedItem = selectedItem;
            $scope.appNavigator.pushPage('homeservice/' + selectedItem.page, {title: selectedItem.title, animation: 'slide'});

        }
        
    });
	
	// End Home Service menu Controller
	
	///// Menu Importent link Controller//////
    app.controller('ImplinkController', function($scope, ImplinkData) {
        $scope.items = ImplinkData.items;
            
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        }
        
    });
	
		///// Metrimony Menu Importent link Controller//////
    app.controller('MetrimonyController', function($scope, MetrimonyData) {
        $scope.items = MetrimonyData.items;
            
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        }
        
    });
	
			///// youtube Menu Importent link Controller//////
    app.controller('YoutubeController', function($scope, YoutubeData) {
        $scope.items = YoutubeData.items;
            
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        }
        
    });
	
	///// Shere App Menu Importent link Controller//////
    app.controller('ShereappController', function($scope, YoutubeData) {
        $scope.items = YoutubeData.items;
            
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            //window.open(url,'_blank');
        }
        
    });
	
///// Banjara Menu Importent link Controller//////
    app.controller('MenuextrnlController', function($scope, BanjaraMenuextData) {
        $scope.items = BanjaraMenuextData.items;
            
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_system');
        }
        
    });
	
	///// Jobs & Scheme Menu Importent link Controller//////
    app.controller('JobsschemeController', function($scope, JobsData) {
        $scope.items = JobsData.items;
            
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        }
        
    });
      
	
    
    // Contact Controller
    app.controller('ContactController', function($scope) {

        $scope.submitForm = function() {
            
            window.plugin.email.open({
                to:      ['govindrathod86@gmail.com'],
                cc:      ['infobanjara@gmail.com'],
                subject: $scope.subject,
                body:    $scope.message
            });

        };

    });
    
   
    
    // Whatsapp Posts Controller
    app.controller('PostsController', function($scope, $http, PostsData) {
        
        $scope.msg = " Wait Loading...";
        
        $http({method: 'GET', url: PostsData.url}).
        success(function(data, status, headers, config) {
            $scope.posts = data.posts;
            
            if ($scope.posts.length < 1)
            {
                $scope.msg = "Nothing found.";
            }else{
                $scope.msg = undefined;
            }

            var page = 1;
            // Define the number of the posts in the page
            var pageSize = 3;

            $scope.paginationLimit = function(data) {
            return pageSize * page;
            };

            $scope.hasMoreItems = function() {
            return page < ($scope.posts.length / pageSize);
            };

            $scope.showMoreItems = function() {
            page = page + 1;       
            }; 
            
        }).
        error(function(data, status, headers, config) {
        $scope.msg = 'An error occured:' + status;
        });
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.posts[index];
        PostsData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/whatsapp-post.html', selectedItem);
        }
        
    });
    
    // Whatsapp  Post Controller
    app.controller('PostController', function($scope, PostsData) {
        $scope.item = PostsData.selectedItem;

        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
		$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

			e.preventDefault();
			var $this = $(this); 
			var target = $this.data('inAppBrowser') || '_blank';

			window.open($this.attr('href'), target);

		});

		
        $scope.sharePost = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.url;

            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }

     });
    
	    // Banjara Latest uodates Posts Controller
    app.controller('LatestupdatesController', function($scope, $http, LatestupdatesData) {
        
        $scope.msg = "Wait Loading...";
        
        $http({method: 'GET', url: LatestupdatesData.url}).
        success(function(data, status, headers, config) {
            $scope.posts = data.posts;
            
            if ($scope.posts.length < 1)
            {
                $scope.msg = "Nothing found.";
            }else{
                $scope.msg = undefined;
            }

            var page = 1;
            // Define the number of the posts in the page
            var pageSize = 3;

            $scope.paginationLimit = function(data) {
            return pageSize * page;
            };

            $scope.hasMoreItems = function() {
            return page < ($scope.posts.length / pageSize);
            };

            $scope.showMoreItems = function() {
            page = page + 1;       
            }; 
            
        }).
        error(function(data, status, headers, config) {
        $scope.msg = 'An error occured:' + status;
        });
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.posts[index];
        LatestupdatesData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/latestupdate.html', selectedItem);
        }
        
    });
    
    // Latest uodate Controller
    app.controller('LatestupdateController', function($scope, LatestupdatesData) {
        $scope.item = LatestupdatesData.selectedItem;

        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.sharePost = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.url;

            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share(message, subject, image, link);
            window.plugins.socialsharing.share(message, subject, null, link);
        }
		



     });
	 
	 
	     // End Latest uodate Controller
	
	

    
  // RSS: Latest News Feeds Controller
    app.controller('FeedsController', function($scope, $http, FeedData, FeedStorage) {
        
        $scope.msg = "Wait Loading...";
        $scope.feeds = "";

        $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(FeedData.url)}).
        success(function(data, status, headers, config) {
            
            if (!data.responseData) {
                $scope.data = FeedStorage.get();
                $scope.msg = "Offline Mode - The device is unable to get the data.";

                $scope.title = $scope.data.feed.title;
                $scope.description = $scope.data.feed.description;
                $scope.link = $scope.data.feed.link;
                $scope.feeds = $scope.data.feed.entries;
            } else {
                $scope.title = data.responseData.feed.title;
                $scope.description = data.responseData.feed.description;
                $scope.link = data.responseData.feed.link;
                $scope.feeds = data.responseData.feed.entries;
                
                // Save feeds to the local storage
                FeedStorage.save(data.responseData);
                
                $scope.msg = "";
            }

        }).
        error(function(data, status, headers, config) {
        
        $scope.data = FeedStorage.get();
        $scope.msg = 'Offline Mode - An error occured:' + status;
            
        $scope.title = $scope.data.feed.title;
        $scope.description = $scope.data.feed.description;
        $scope.link = $scope.data.feed.link;
        $scope.feeds = $scope.data.feed.entries;  
            
        });

        var page = 1;
        // Define the number of the feed results in the page
        var pageSize = 5;

        $scope.paginationLimit = function(data) {
        return pageSize * page;
        };
        
        $scope.hasMoreItems = function() {
        return page < ($scope.feeds.length / pageSize);
        };

        $scope.showMoreItems = function() {
        page = page + 1;       
        }; 
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.feeds[index];
        FeedData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/feed.html', selectedItem);
        }
        
    });
    
    // RSS: Feed Controller
    app.controller('FeedController', function($scope, FeedData) {
        $scope.item = FeedData.selectedItem;
        
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });
	 
	 	 // End latest news feed RSS: Feeds (2) Controller
	 
	 // GoarBanjara RSS: Feeds (2) Controller
app.controller('Feeds2Controller', function($scope, $http, Feed2Data, Feed2Storage) {

    $scope.msg = "Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed2Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed2Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed2Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed2Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed2Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/goarbanjara-feed.html', selectedItem);
    }

});

// RSS: Feed (2) Controller
app.controller('Feed2Controller', function($scope, Feed2Data) {
    $scope.item = Feed2Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
		
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
        
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // GoarBanjara End Feed 2 controller
	 
	 
	
 
 // RajBanjara RSS: Feeds (3) Controller
app.controller('Feeds3Controller', function($scope, $http, Feed3Data, Feed3Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed3Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed3Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed3Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed3Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed3Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/rajbanjara-feed.html', selectedItem);
    }

});

// RSS: Feed 3 Controller
app.controller('Feed3Controller', function($scope, Feed3Data) {
    $scope.item = Feed3Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // RajBanjara End Feed 3 controller
    
	
	
 // Bajara Pukar RSS: Feeds (3) Controller
app.controller('Feeds4Controller', function($scope, $http, Feed4Data, Feed4Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed4Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed4Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed4Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed4Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed4Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/banjarapukar-feed.html', selectedItem);
    }

});

// RSS: Feed 4 Controller
app.controller('Feed4Controller', function($scope, Feed4Data) {
    $scope.item = Feed4Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
		
		
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
        
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Banjara Pukar End Feed 4 controller
  
  // Bajara Darpan RSS: Feeds (5) Controller
app.controller('Feeds5Controller', function($scope, $http, Feed5Data, Feed5Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed5Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed5Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed5Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed5Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed5Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/banjaradarpan-feed.html', selectedItem);
    }

});

// RSS: Feed 5 Controller
app.controller('Feed5Controller', function($scope, Feed5Data) {
    $scope.item = Feed5Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Banjara Bandhu End Feed 5 controller
  
  
 // Bajara Darpan RSS: Feeds (6) Controller
app.controller('Feeds6Controller', function($scope, $http, Feed6Data, Feed6Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed6Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed6Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed6Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed6Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed6Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/banjarabandhu-feed.html', selectedItem);
    }

});

// RSS: Feed 6 Controller
app.controller('Feed6Controller', function($scope, Feed6Data) {
    $scope.item = Feed6Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Banjara Darpan End Feed 6 controller
  
  
 // Bajara Chetna RSS: Feeds (7) Controller
app.controller('Feeds7Controller', function($scope, $http, Feed7Data, Feed7Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed7Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed7Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed7Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed7Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed7Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/banjarachetna-feed.html', selectedItem);
    }

});

// RSS: Feed 7 Controller
app.controller('Feed7Controller', function($scope, Feed7Data) {
    $scope.item = Feed7Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Banjara Chetna End Feed 7 controller
  
  
 // Bajara GoaarJagruti RSS: Feeds (8) Controller
app.controller('Feeds8Controller', function($scope, $http, Feed8Data, Feed8Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed8Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed8Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed8Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed8Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed8Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/goaarjagruti-feed.html', selectedItem);
    }

});

// RSS: Feed 8 Controller
app.controller('Feed8Controller', function($scope, Feed8Data) {
    $scope.item = Feed8Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Banjara GoaarJagruti End Feed 8 controller
 
 // Ancient Bajara History  RSS: Feeds (9) Controller
app.controller('Feeds9Controller', function($scope, $http, Feed9Data, Feed9Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed9Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed9Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed9Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed9Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed9Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/ancient-history.html', selectedItem);
    }

});

//  Ancient Banjara History  RSS: Feed 8 Controller
app.controller('Feed9Controller', function($scope, Feed9Data) {
    $scope.item = Feed9Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Ancient Banjara History  End Feed 9 controller
 
  // Sant sevalal History  RSS: Feeds (10) Controller
app.controller('Feeds10Controller', function($scope, $http, Feed10Data, Feed10Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed10Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed10Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed10Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed10Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed10Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/sant-sevalal-history.html', selectedItem);
    }

});

//  Sant sevalal History  RSS: Feed 10 Controller
app.controller('Feed10Controller', function($scope, Feed10Data) {
    $scope.item = Feed10Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Sant Sevalal History  End Feed 10 controller
 
 
   // Health Feeds RSS: Feeds (11) Controller
app.controller('Feeds11Controller', function($scope, $http, Feed11Data, Feed11Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed11Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed11Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed11Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed11Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed11Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('news/health-feed.html', selectedItem);
    }

});

	
// Read old entries link  Importent link Controller

	    app.controller('ReadoldController', function($scope, ReadoldData) {
        $scope.items = LatestData.items;
            
        $scope.loadURL = function (url) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(url,'_system');
        }
        
    });
	
//    RSS: Feed 11 Controller
app.controller('Feed11Controller', function($scope, Feed11Data) {
    $scope.item = Feed11Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Health  End Feed 11 controller
  
    //Jobs Scheme Feeds RSS: Feeds (12) Controller
app.controller('Feeds12Controller', function($scope, $http, Feed12Data, Feed12Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed12Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed12Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed12Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed12Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed12Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('other/jobs-scheme-feed.html', selectedItem);
    }

});

//   RSS: Feed 12 Controller
app.controller('Feed12Controller', function($scope, Feed12Data) {
    $scope.item = Feed12Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 //Jobs and Scheme End Feed 12 controller
  
   //Youtube Feeds RSS: Feeds (13) Controller
app.controller('Feeds13Controller', function($scope, $http, Feed13Data, Feed13Storage) {

    $scope.msg = "Wait Loading...";
    $scope.feeds = "";

    $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(Feed13Data.url)}).
    success(function(data, status, headers, config) {

        if (!data.responseData) {
            $scope.data = Feed13Storage.get();
            $scope.msg = "Offline Mode - The device is unable to get the data.";

            $scope.title = $scope.data.feed.title;
            $scope.description = $scope.data.feed.description;
            $scope.link = $scope.data.feed.link;
            $scope.feeds = $scope.data.feed.entries;
        } else {
            $scope.title = data.responseData.feed.title;
            $scope.description = data.responseData.feed.description;
            $scope.link = data.responseData.feed.link;
            $scope.feeds = data.responseData.feed.entries;

            // Save feeds to the local storage
            Feed13Storage.save(data.responseData);

            $scope.msg = "";
        }

    }).
    error(function(data, status, headers, config) {

    $scope.data = Feed13Storage.get();
    $scope.msg = 'Offline Mode - An error occured:' + status;

    $scope.title = $scope.data.feed.title;
    $scope.description = $scope.data.feed.description;
    $scope.link = $scope.data.feed.link;
    $scope.feeds = $scope.data.feed.entries;  

    });

    var page = 1;
    // Define the number of the feed results in the page
    var pageSize = 5;

    $scope.paginationLimit = function(data) {
    return pageSize * page;
    };

    $scope.hasMoreItems = function() {
    return page < ($scope.feeds.length / pageSize);
    };

    $scope.showMoreItems = function() {
    page = page + 1;       
    }; 

    $scope.showDetail = function(index) {
    var selectedItem = $scope.feeds[index];
    Feed13Data.selectedItem = selectedItem;
    $scope.appNavigator.pushPage('other/youtube-feed.html', selectedItem);
    }

});

//   RSS: Feed 13 Controller
app.controller('Feed13Controller', function($scope, Feed13Data) {
    $scope.item = Feed13Data.selectedItem;

     $scope.loadURL = function (link) {
            //target: The target in which to load the URL, an optional parameter that defaults to _self. (String)
            //_self: Opens in the Cordova WebView if the URL is in the white list, otherwise it opens in the InAppBrowser.
            //_blank: Opens in the InAppBrowser.
            //_system: Opens in the system's web browser.
            window.open(link,'_blank');
        }
        
		// Open any external link with InAppBrowser Plugin
			$(document).on('click', 'a[href^=http], a[href^=https]', function(e){

				e.preventDefault();
				var $this = $(this); 
				var target = $this.data('inAppBrowser') || '_blank';

				window.open($this.attr('href'), target);

			});
		
        $scope.shareFeed = function () {
            
            var subject = $scope.item.title;
            var message = $scope.item.content;
            message = message.replace(/(<([^>]+)>)/ig,"");

            var link = $scope.item.link;
            
            //Documentation: https://github.com/EddyVerbruggen/SocialSharing-PhoneGap-Plugin
            //window.plugins.socialsharing.share('Message', 'Subject', 'Image', 'Link');
            window.plugins.socialsharing.share(message, subject, null, link);
        }
        
     });

 // Youtube Feed End Feed 13 controller
  
  // Gallery Controller
    app.controller('GalleryController', function($scope, GalleryData) {

        var items = GalleryData.items;

        function addSlides(target) {
            angular.forEach(items,function(item,index){
                target.push({
                    //label: item.label,
                    picture: item.src,
                    //location: item.location,
                    item: (index + 1)
                });
            });
         };

        $scope.slides = [];
        addSlides($scope.slides);

    });

    // Settings Controller
    app.controller('SettingsController', function($scope, SettingsData, localStorageService, FeedStorage) {
        $scope.settings = SettingsData.items;

        if (localStorageService.get('settings')) {
            $scope.settings = localStorageService.get('settings');
        }
        
        $scope.saveSettings = function() {
            localStorageService.clearAll();
            localStorageService.add('settings',$scope.settings);
        };
        
        $scope.clearLocalStorage = function() {
        FeedStorage.clear();
        }
        
    });
    

    
    // Banjara Community Feed Plugin: Categories Controller // Feed page //
    app.controller('FeedPluginCategoriesController', function($scope, $http, FeedPluginData) {

        $http({method: 'GET', url: FeedPluginData.url}).
        success(function(data, status, headers, config) {
            $scope.categories = data.categories; 
        }).
        error(function(data, status, headers, config) {

        });

        $scope.showDetail = function(index) {
        var selectedItem = $scope.categories[index];
        FeedPluginData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/feed-category.html', {title : selectedItem.title});
        }

    });
    
    // Feed Plugin: Category Controller
    app.controller('FeedPluginCategoryController', function($scope, FeedPluginData) {

        $scope.title = FeedPluginData.selectedItem.title;
        $scope.items = FeedPluginData.selectedItem.items;

        $scope.showDetail = function(index) {
        var selectedItem = $scope.items[index];
        FeedPluginData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/feed-master.html', {title : selectedItem.title});
        }

    });
    
    // Feed Plugin: Master Controller
    app.controller('FeedPluginMasterController', function($scope, $http, FeedPluginData) {
        
        $scope.msg = "Wait Loading...";
        $scope.feeds = "";

        $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(FeedPluginData.selectedItem.url)}).
        success(function(data, status, headers, config) {
            
            if (!data.responseData) {
                $scope.msg = "The device is unable to get the data.";
            } else {
                $scope.title = data.responseData.feed.title;
                $scope.description = data.responseData.feed.description;
                $scope.link = data.responseData.feed.link;
                $scope.feeds = data.responseData.feed.entries;
                
                $scope.msg = "";
            }

        }).
        error(function(data, status, headers, config) {
        $scope.msg = 'An error occured:' + status; 
        });

        var page = 1;
        // Define the number of the feed results in the page
        var pageSize = 4;

        $scope.paginationLimit = function(data) {
        return pageSize * page;
        };
        
        $scope.hasMoreItems = function() {
        return page < ($scope.feeds.length / pageSize);
        };

        $scope.showMoreItems = function() {
        page = page + 1;       
        }; 
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.feeds[index];
        FeedPluginData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/feed-detail.html', selectedItem);
        }
        
		$scope.mediaObject = function(item) {
			return (item && item.mediaGroups) ? item.mediaGroups[0].contents[0] : {url:''};
		}

		$scope.hasVideo = function(item) {
			var media = $scope.mediaObject(item);
            
            //JAVASCRIPT: condition ? val1 : val2
            //return media.type ? (media.type == "video/mp4") : (media.url ? (media.url.indexOf(".mp4") != -1) : false);
			return media.type ? (media.type == "video/mp4") : false;
		}
        
		$scope.hasAudio = function(item) {
			var media = $scope.mediaObject(item);
            
            //JAVASCRIPT: condition ? val1 : val2
			return media.type ? (media.type == "audio/mp3") : false;
		}
        
        
        
    });

    
    // Feed Plugin: Category Controller
    app.controller('FeedPluginCategoryController', function($scope, FeedPluginData) {

        $scope.title = FeedPluginData.selectedItem.title;
        $scope.items = FeedPluginData.selectedItem.items;

        $scope.showDetail = function(index) {
        var selectedItem = $scope.items[index];
        FeedPluginData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/feed-master.html', {title : selectedItem.title});
        }

    });
    
    // Feed Plugin: Master Controller
    app.controller('FeedPluginMasterController', function($scope, $http, FeedPluginData) {
        
        $scope.msg = "Wait Loading...";
        $scope.feeds = "";

        $http({method: 'JSONP', url: 'http://ajax.googleapis.com/ajax/services/feed/load?v=1.0&num=50&callback=JSON_CALLBACK&q=' + encodeURIComponent(FeedPluginData.selectedItem.url)}).
        success(function(data, status, headers, config) {
            
            if (!data.responseData) {
                $scope.msg = "The device is unable to get the data.";
            } else {
                $scope.title = data.responseData.feed.title;
                $scope.description = data.responseData.feed.description;
                $scope.link = data.responseData.feed.link;
                $scope.feeds = data.responseData.feed.entries;
                
                $scope.msg = "";
            }

        }).
        error(function(data, status, headers, config) {
        $scope.msg = 'An error occured:' + status; 
        });

        var page = 1;
        // Define the number of the feed results in the page
        var pageSize = 4;

        $scope.paginationLimit = function(data) {
        return pageSize * page;
        };
        
        $scope.hasMoreItems = function() {
        return page < ($scope.feeds.length / pageSize);
        };

        $scope.showMoreItems = function() {
        page = page + 1;       
        }; 
        
        $scope.showDetail = function(index) {
        var selectedItem = $scope.feeds[index];
        FeedPluginData.selectedItem = selectedItem;
        $scope.appNavigator.pushPage('news/feed-detail.html', selectedItem);
        }
        
		$scope.mediaObject = function(item) {
			return (item && item.mediaGroups) ? item.mediaGroups[0].contents[0] : {url:''};
		}

		$scope.hasVideo = function(item) {
			var media = $scope.mediaObject(item);
            
            //JAVASCRIPT: condition ? val1 : val2
            //return media.type ? (media.type == "video/mp4") : (media.url ? (media.url.indexOf(".mp4") != -1) : false);
			return media.type ? (media.type == "video/mp4") : false;
		}
        
		$scope.hasAudio = function(item) {
			var media = $scope.mediaObject(item);
            
            //JAVASCRIPT: condition ? val1 : val2
			return media.type ? (media.type == "audio/mp3") : false;
		}
        
        
        
    });
    
    // NVD3 View: NVD3 Controller
    app.controller('NVD3Controller', function($scope, NVD3Data) {
        
        var data = NVD3Data;
        
        /* Chart options */
        $scope.options = data.options;

        /* Chart data */
        $scope.data = data.data;
        
     });
    
    // PLUGINS: Device Controller
    app.controller('DeviceController', function($scope) {
        
        $scope.device = device;
        
    });
    
    // PLUGINS: Geolocation Controller
    app.controller('GeolocationController', function($scope) {

        $scope.latitude = '0';
        $scope.longitude = '0';
        $scope.accuracy = '0';
        $scope.altitude = '0';
        $scope.altitudeAccuracy = '0';
        $scope.heading = '0';
        $scope.speed = '0';
        $scope.timestamp = '0';
        $scope.error = '';
        $scope.model = { map: undefined };
        $scope.markers = [];
 
        $scope.showResult = function () {
            return $scope.error == '';
        }
 
        $scope.mapOptions = {
            center: new google.maps.LatLng($scope.latitude, $scope.longitude),
            zoom: 15,
            mapTypeId: google.maps.MapTypeId.ROADMAP
        };
 
        $scope.showPosition = function (position) {
            $scope.latitude = position.coords.latitude;
            $scope.longitude = position.coords.longitude;
            $scope.accuracy = position.coords.accuracy;
            $scope.altitude = position.coords.altitude;
            $scope.altitudeAccuracy = position.coords.altitudeAccuracy;
            $scope.heading = position.coords.heading;
            $scope.speed = position.coords.speed;
            $scope.timestamp = position.timestamp;
            $scope.$apply();
 
            var latlng = new google.maps.LatLng($scope.latitude, $scope.longitude);
            $scope.model.map.setCenter(latlng);
            $scope.markers.push(new google.maps.Marker({ map: $scope.model.map, position: latlng }));
        }
 
        $scope.showError = function (error) {
            switch (error.code) {
                case error.PERMISSION_DENIED:
                    $scope.error = "User does not allow the app to retrieve position information."
                    break;
                case error.POSITION_UNAVAILABLE:
                    $scope.error = "The device is unable to retrieve a position. In general, this means the device is not connected to a network or can't get a satellite fix."
                    break;
                case error.TIMEOUT:
                    $scope.error = "The request to get user location timed out."
                    break;
                case error.UNKNOWN_ERROR:
                    $scope.error = "An unknown error occurred."
                    break;
            }
            $scope.$apply();
        }
 
        $scope.getLocation = function () {
            if (navigator.geolocation) {
                var options = { enableHighAccuracy: true };
                navigator.geolocation.getCurrentPosition($scope.showPosition, $scope.showError, options);
            }
            else {
                $scope.error = "Geolocation is not supported by this browser.";
            }
        }
 
        $scope.getLocation();

    });
    
    // PLUGINS: Notifications Controller
    app.controller('NotificationsController', function($scope) {
        
        $scope.alertNotify = function() {
        navigator.notification.alert("Sample Alert",function() {console.log("Alert success")},"My Alert","Close");
        };

        $scope.beepNotify = function() {
        navigator.notification.beep(1);
        };

        $scope.vibrateNotify = function() {
        navigator.notification.vibrate(3000);
        };

        $scope.confirmNotify = function() {
        navigator.notification.confirm("My Confirmation",function(){console.log("Confirm Success")},"Are you sure?",["Ok","Cancel"]);
        };
        
    });
    
    // Barcodescanner Controller
    app.controller('BarcodescannerController', function($scope) {
        
        $scope.scan = function() {
            cordova.plugins.barcodeScanner.scan(function(result) {
                $scope.result = result;
                $scope.$apply();
            }, function(error) {
                $scope.error = error;
                $scope.$apply();
            });
        }
        
    });
    
    // Filter
    app.filter('partition', function($cacheFactory) {
          var arrayCache = $cacheFactory('partition');
          var filter = function(arr, size) {
            if (!arr) { return; }
            var newArr = [];
            for (var i=0; i<arr.length; i+=size) {
                newArr.push(arr.slice(i, i+size));        
            }
            var cachedParts;
            var arrString = JSON.stringify(arr);
            cachedParts = arrayCache.get(arrString+size); 
            if (JSON.stringify(cachedParts) === JSON.stringify(newArr)) {
              return cachedParts;
            }
            arrayCache.put(arrString+size, newArr);
            return newArr;
          };
          return filter;
        });


})();